Learn R Programming

aplms (version 0.1.0)

family.elliptical: Family Objects for Elliptical Models

Description

The family object provide an specify details of the model APLMS. The distribution functions are necessary to specify the random component of the regression models with elliptical errors. The code is derived from the archived package gwer (Araujo, Y.A., Cysneiros, F.J.A., and Cysneiros, A.H.M.A., 2022), originally available on CRAN.

Usage

# S3 method for elliptical
family(object, ...)

Normal()

Cauchy()

LogisI()

LogisII()

Student(df = stop("no df argument"))

Powerexp(k = stop("no k argument"))

Glogis(parma = stop("no alpha=alpha(m) or m argument"))

Gstudent(parm = stop("no s or r argument"))

Cnormal(parmt = stop("no epsi or sigma argument"))

GNormal(nu = stop("no nu argument"))

Value

An object of class “family” specifying a list with the follows elements:

family

character: the family name.

g0, g1, g2, g3, g4, g5

derived fuctions associated with the distribution family defined.

df

degree of freedom for t-Student distribution.

s, r

shape parameters for generalized t-Student distribution.

alpha

shape parameter for contaminated normal and generalized logistic distributions.

mp

shape parameter for generalized logistic distribution.

epsi,sigmap

dispersion parameters for contaminated normal distribution.

k

shape parameter for power exponential distribution.

a famility elliptical object using a Normal distribution.

a famility elliptical object using a Couchy distribution.

a famility elliptical object using a LogisI distribution.

a famility elliptical object using a LogisII distribution.

a famility elliptical object using a Student distribution with a specific degrees of freedom.

a famility elliptical object using an exponential distribution.

a famility elliptical object using a Glogis distribution.

a famility elliptical object using a Gstudent distribution.

a famility elliptical object using a Cnormal distribution

a famility elliptical object using a Gnormal distribution

Arguments

object

an object with the result of the fitted elliptical regression model.

...

arguments to be used to form the default control argument if it is not supplied directly.

df

degrees of freedom.

k

shape parameter.

parma

parameter vector (alpha, m).

parm

parameter vector (s, r) for this distribuition.

parmt

parameters vector (epsi, sigma).

nu

degrees of freedom.

References

Fang, K. T., Kotz, S. and NG, K. W. (1990, ISBN:9781315897943). Symmetric Multivariate and Related Distributions. London: Chapman and Hall.

Examples

Run this code
Normal()
Powerexp(k=0.1)

Run the code above in your browser using DataLab